# Tcl package index file, version 1.1
# This file is generated by the "pkg_mkIndex -direct" command
# and sourced either when an application starts up or
# by a "package unknown" script.  It invokes the
# "package ifneeded" command to set up package-related
# information so that packages will be loaded automatically
# in response to "package require" commands.  When this
# script is sourced, the variable $dir must contain the
# full path name of this file's directory.

package ifneeded tkdvi 0.3 [list source [file join $dir tkdvi.tcl]]
package ifneeded tkdvi::browser 0.2 [list source [file join $dir browser.tcl]]
package ifneeded tkdvi::browser::special::bookmark 1.0 [list source [file join $dir specBM.tcl]]
package ifneeded tkdvi::browser::special::info 1.0 [list source [file join $dir specInfo.tcl]]
package ifneeded tkdvi::browser::special::ps 1.0 [list source [file join $dir specPS.tcl]]
package ifneeded tkdvi::browser::special::src 1.0 [list source [file join $dir specSrc.tcl]]
package ifneeded tkdvi::dialog 0.1 [list source [file join $dir dialog.tcl]]
package ifneeded tkdvi::menu 1.0 [list source [file join $dir menu.tcl]]
package ifneeded tkdvi::pagesel 2.0 [list source [file join $dir pagesel.tcl]]
